#!/bin/bash
# Description: This file is the network performance diagnostic test script for 
# the pNFS regression suite and performance debugging tool chain. It calculates the performance of the link between all the nodes.
# Stage: 0 
# Author: Zainul Abedin (zja) & Swaroop Choudhari (svchoudh)
# Inputs: 
# Detailed Description: 
# Stage0 of the test suite is used to get Experimental setup information. 

export RSH=ssh
count="0"

declare -a mount_points

if (([ -s "$client_list" ]) && ([ -r "$client_list" ]))
    then
    if (([ -s "$mount_point_list" ]) && ([ -r "$mount_point_list" ]))
	then
	for mount_point in `cat "$mount_point_list"`; do
	    mount_points[i]=$mount_point
	    let "i=$i+1"
	done
    else
	#output error and exit
	echo "ERROR reading mount point list of clients:" $mount_point_list "No such file"
	exit -1
    fi
else
    #output error and exit.
    echo "ERROR reading mount point list of clients:" $client_list "No such file"
    exit -1
fi

if [ $TCP_DUMP -ne 0 ]; then 
    dsh -a -c -- "tcpdump -s 0 -w /tmp/"$SAVE_AS"_autoreport_tcpdata" &
fi


declare -a partitions

let "i=0"

if [ $IOSTAT -ne 0 ]; then 
    if (([ -s "$partition_list" ]) && ([ -r "$partition_list" ]))
	then
	for partition in `cat "$partition_list"`; do
	    partitions[i]=$partition
	    let "i=$i+1"
	done
    fi
    let "i=0"
    for server in `cat $storage_nodes_list`;do
	dsh -m $server -- " iostat -d ${partitions[$i]} -k 5 > "$SAVE_AS"_autoreport_iostatdata " &
	let "i=$i+1"
    done
fi


sleep 2

# Run iozone for all clients.
let "i=0"
for client in `cat $client_list`; do
    let "count=1"
    read_name=""
    write_name=""
    while [ "$count" -le "$num_runs" ]; do
	echo ${mount_points[$i]}
	dsh -m $client -- "export RSH=ssh && iozone -f${mount_points[$i]}/iozone_temp -Race -i0 -i1 -+n > "$PATH_TO_SAVE"single_client_autoreport_run"$count""
	dsh -m $client -- "parse_singleclient_output.sh "$PATH_TO_SAVE"single_client_autoreport_run"$count" write"
	dsh -m $client -- "parse_singleclient_output.sh "$PATH_TO_SAVE"single_client_autoreport_run"$count" read"
	dsh -m $client -- "rm -rf "$PATH_TO_SAVE"single_client_autoreport_run"$count" "
	read_name="$read_name"' '"$PATH_TO_SAVE"read_single_client_autoreport_run"$count".txt
	write_name="$write_name"' '"$PATH_TO_SAVE"write_single_client_autoreport_run"$count".txt
	let "count=$count+1"
    done
    dsh -m $client -- "insert_iozone_singleclient $DB_SERVER $VERSION $FS write \"$SAVE_AS\" 1 $client $num_runs$write_name"
    dsh -m $client -- "insert_iozone_singleclient $DB_SERVER $VERSION $FS read \"$SAVE_AS\" 1 $client $num_runs$read_name"
    dsh -m $client -- "rm -rf $write_name $read_name"
    let "i=$i+1"
done

if [ $TCP_DUMP -ne 0 ]; then 
    dsh -a -c -- " killall -s SIGKILL tcpdump"
fi


if [ $IOSTAT -ne 0 ]; then 
    dsh -gstorage_nodes -c -- " killall -s SIGKILL iostat"
fi


