#!/bin/bash
# File : preg_config.sh
# Description: 
# This file is a sample config file to run all the p-reg tests using just a config file. 

# The different stages of the test are: 
# 1. Stage 0 - Diagnostic test phase.
# 2. Stage 1 - Performance regression runs.
# Author: Zainul Abedin (zja) & Swaroop Choudhari (svchoudh)
# Inputs: 
# Detailed Description: 


export PATH_TO_SAVE='/tmp/'
export SAVE_AS="pnfs-2-6-16_run2"


#variables of stage 0. 
# Set to 1 if you would like to run STAGE ZERO (DIAGNOSTIC PHASE) of the performance regression suite.
export RUN_STAGE_ZERO=1
export STAGE_ZERO_num_runs=1
# Set to 1 if you would like to run disk diagnostic tests of the performance regression suite.
export DISK_PERFORMANCE=1

# list of all the storage nodes and the disk where the data is stored on them.
# These files contain one name per line.
export storage_nodes_list='/usr/local/etc/group/storage_nodes'
export disk_list="disk_list"

# Set to 1 if you would like to run raw network diagnostic tests of the performance regression suite.
export RAW_NETWORK_PERFORMANCE=1
# list of all the machines in the system. This file contains one name per line.
export nodes_list='/usr/local/etc/machines.list'

#variables of stage 1.
# Set to 1 if you would like to run STAGE ONE (REGRESSION PHASE) of the performance regression suite.
export RUN_STAGE_ONE=1

# Assign to the version of the code base.
export VERSION="2-6-17"
# Assign to the underlying File system used.
export FS="PVFS"

# Set to 1 if you would like to run single client tests of the performance regression suite.
export SINGLE_CLIENT=1
export SINGLE_CLIENT_num_runs=1
# list of all client nodes. one name per line.
export client_list='/root/bin/clients'
export mount_point_list='/root/bin/mountpoint_list'
# Set to 1 if you would like to generate single client read write autoreport (File size varies from 64k to 512M, Record size varies from 4k to 16M)
export SINGLE_CLIENT_AUTOREPORT=1

# SINGLE_CLIENT_LARGEFILES: Set to 1 if you would like to run single client large file tests. 
# min_largefile_size: Minimum file size for this particular test (in KBytes)
# max_largefile_size: Maximum file size for this particular test (in KBytes)
# largefile_recordsize: Record size or syscall size to use to write/read the file. (in KBytes)
export SINGLE_CLIENT_LARGEFILES=1
export min_largefile_size=524288 #512MB
export max_largefile_size=8290304 #8GB
export largefile_recordsize=4096 #4MB

# SINGLE_CLIENT_SMALLFILES: Set to 1 if you would like to run single client large file tests. 
# min_smallfile_size: Minimum file size for this particular test (in KBytes)
# max_smallfile_size: Maximum file size for this particular test (in KBytes)
# smallfile_recordsize: Record size or syscall size to use to write/read the file. (in KBytes)
export SINGLE_CLIENT_SMALLFILES=0
export min_smallfile_size=64
export max_smallfile_size=4096
export smallfile_recordsize=4

# Set to 1 if you would like to run multiple client tests of the performance regression suite.
export MULTIPLE_CLIENTS=0
export MULTIPLE_CLIENTS_num_runs=1
export min_num_clients="1"
export max_num_clients="3"
export recordsize_list='/root/bin/recordsize_list'
export filesize_list='/root/bin/filesize_list'
export client_config_file="/root/bin/client_list"


#Run p-reg
./p-reg.sh