#!/bin/bash
# Description: This file is the STAGE 1 script for 
# the pNFS regression suite and performance debugging tool chain. 
# Stage: 1
# Author: Zainul Abedin (zja) & Swaroop Choudhari (svchoudh)
# Inputs: \
# Detailed Description: 
# Stage1 of the test suite is used to run performance tests on the system.

export RSH=ssh

 

if [ $SINGLE_CLIENT -ne 0 ]; then
    export num_runs=$SINGLE_CLIENT_num_runs
    if [ $SINGLE_CLIENT_AUTOREPORT -ne 0 ]; then
	#Run single client autoreport generation.
	iozone_single_client_autoreport.sh
    fi
    if [ $SINGLE_CLIENT_LARGEFILES -ne 0 ]; then 
	# Run single client file with large file sizes and specified record size.
	echo "./iozone_single_client_file_size.sh $min_largefile_size $max_largefile_size $largefile_recordsize"
	
	if [ $TCP_DUMP -ne 0 ]; then 
	    dsh -a -c -- "tcpdump -s 0 -w /tmp/"$SAVE_AS"_largefiles_tcpdata" &
	fi
	
	
	declare -a partitions
	
	let "i=0"

	if [ $IOSTAT -ne 0 ]; then 
	    if (([ -s "$partition_list" ]) && ([ -r "$partition_list" ]))
		then
		for partition in `cat "$partition_list"`; do
		    partitions[i]=$partition
		    let "i=$i+1"
	done
	    fi
	    let "i=0"
	    for server in `cat $storage_nodes_list`;do
		dsh -m $server -- " iostat -d ${partitions[$i]} -k 5 > "$SAVE_AS"_largefiles_iostatdata " &
		let "i=$i+1"
	    done
	fi
	
	
	sleep 2

	iozone_single_client_file_size.sh $min_largefile_size $max_largefile_size $largefile_recordsize "large"
	
	if [ $TCP_DUMP -ne 0 ]; then 
	    dsh -a -c -- " killall -s SIGKILL tcpdump"
	fi
	
	
	if [ $IOSTAT -ne 0 ]; then 
	    dsh -gstorage_nodes -c -- " killall -s SIGKILL iostat"
	fi

    fi

    if [ $SINGLE_CLIENT_SMALLFILES -ne 0 ]; then
	# Run single client with specified range of small files and specified record size.
	
	if [ $TCP_DUMP -ne 0 ]; then 
	    dsh -a -c -- "tcpdump -s 0 -w /tmp/"$SAVE_AS"_smallfiles_tcpdata" &
	fi
	
	
	declare -a partitions
	
	let "i=0"

	if [ $IOSTAT -ne 0 ]; then 
	    if (([ -s "$partition_list" ]) && ([ -r "$partition_list" ]))
		then
		for partition in `cat "$partition_list"`; do
		    partitions[i]=$partition
		    let "i=$i+1"
	done
	    fi
	    let "i=0"
	    for server in `cat $storage_nodes_list`;do
		dsh -m $server -- " iostat -d ${partitions[$i]} -k 5 > "$SAVE_AS"_smallfiles_iostatdata " &
		let "i=$i+1"
	    done
	fi
	
	
	sleep 2

	iozone_single_client_file_size.sh $min_smallfile_size $max_smallfile_size $smallfile_recordsize "small"
	
	if [ $TCP_DUMP -ne 0 ]; then 
	    dsh -a -c -- " killall -s SIGKILL tcpdump"
	fi
	
	
	if [ $IOSTAT -ne 0 ]; then 
	    dsh -gstorage_nodes -c -- " killall -s SIGKILL iostat"
	fi

    fi
fi

if [ $MULTIPLE_CLIENTS -ne 0 ]; then
    export num_runs=$MULTIPLE_CLIENTS_num_runs
    # Run iozone with multiple clients with the specified range of file size and specified record size.
    iozone_multi_client.sh        
fi
